Switch to side-by-side view

--- a/src/internfile/mh_exec.h
+++ b/src/internfile/mh_exec.h
@@ -38,7 +38,8 @@
 class MimeHandlerExec : public RecollFilter {
  public:
     ///////////////////////
     // Members not reset by clear(). params, cfgMtype and chgCharset
     // define what I am.  missingHelper is a permanent error
     // (no use to try and execute over and over something that's not
     // here).
@@ -48,11 +49,11 @@
     list<string> params;
     // Filter output type. The default for ext. filters is to output html, 
     // but some don't, in which case the type is defined in the config.
-    string cfgMtype;
+    string cfgFilterOutputMtype;
     // Output character set if the above type is not text/html. For
     // those filters, the output charset has to be known: ie set by a command
     // line option.
-    string cfgCharset; 
+    string cfgFilterOutputCharset; 
     bool missingHelper;
     ////////////////
@@ -38,7 +38,8 @@
  public:
     ///////////////////////
-    // Members not reset by clear(). params, cfgMtype and chgCharset
+    // Members not reset by clear(). params, cfgFilterOutputMtype and 
+    // cfgFilterOutputCharset
     // define what I am.  missingHelper is a permanent error
     // (no use to try and execute over and over something that's not